@@ -138,7 +138,7 @@ def backtest(
     save_dataframe_to_csv(
         dfs_results[0],
         string_name='backtesting_result_metrics',
-        string_directory='assets/results',
+        string_directory=display_options['string_results_directory'],
     )
 
     comments = {
@@ -213,7 +213,7 @@ def plot_robustness_heatmap(
     figure.colorbar(points)
 
     try:
-        string_directory = 'assets/results'
+        string_directory = display_options['string_results_directory']
         result_no = len(
             [name for name in os.listdir(string_directory) if os.path.isfile(
                 os.path.join(
@@ -223,7 +223,7 @@ def plot_robustness_heatmap(
             )]
         ) / 2
     except:
-        string_directory = 'backtesting/results'
+        string_directory = display_options['string_results_directory']
         result_no = len(
             [name for name in os.listdir(string_directory) if os.path.isfile(
                 os.path.join(
@@ -275,7 +275,7 @@ def backtest_visualizer(
     dict_backtesting = backtest(
         file_path_with_price_data=file_path_with_price_data,
         file_path_with_token_data=file_path_with_token_data,
-        name_of_foreign_key_in_price_dataf_table=name_of_foreign_key_in_price_data_table,
+        name_of_foreign_key_in_price_data_table=name_of_foreign_key_in_price_data_table,
         name_of_foreign_key_in_token_metadata_table=name_of_foreign_key_in_token_metadata_table,
         float_budget_in_usd=float_budget_in_usd,
         margin_loan_rate=margin_loan_rate,
