@@ -473,7 +473,7 @@ def evaluate_performance(
         save_dataframe_to_csv(
             df_daily_returns,
             string_name='df_daily_returns',
-            string_directory='assets/results',
+            string_directory=display_options['string_results_directory'],
         )
 
         beginning_benchmark_value = find_dataframe_value_with_keywords(
@@ -638,26 +638,15 @@ def plot_equity_curve(
         boolean_save_to_disk=True
     ):
     """Creates an equity based on daily returns."""
-    try:
-        string_directory = 'assets/results'
-        result_no = len(
-            [name for name in os.listdir(string_directory) if os.path.isfile(
-                os.path.join(
-                    string_directory,
-                    name
-                )
-            )]
-        ) / 2
-    except:
-        string_directory = 'backtesting/results'
-        result_no = len(
-            [name for name in os.listdir(string_directory) if os.path.isfile(
-                os.path.join(
-                    string_directory,
-                    name
-                )
-            )]
-        ) / 2
+    string_directory = display_options['string_results_directory']
+    result_no = len(
+        [name for name in os.listdir(string_directory) if os.path.isfile(
+            os.path.join(
+                string_directory,
+                name
+            )
+        )]
+    ) / 2
 
     number_of_result_files_plus_1 = 1 + int(result_no)
 
